(* $Id: godi_perform.mli 426 2004-05-07 22:00:28Z gerd $
 * ----------------------------------------------------------------------
 * Copyright 2003 by Gerd Stolpmann.
 *
 * This file is part of godi-tools.
 *
 * godi-tools is free software; you can redistribute it and/or modify it
 * under the conditions in the file LICENSE.
 *
 * godi-tools is distributed WITHOUT ANY WARRANTY, as detailed in the
 * file LICENSE.
 *)

(* Perform a build plan *)

open Godi_types
open Godi_exec


val fetch_pkg : 
      ?pref_user_error:bool ->
      ?interactivity:interactivity ->
      ?protocol:collector ->
      package ->
	unit
  (* Ensures that the sources for a source package are locally available.
   * If not, the sources are downloaded. Dependencies are ignored.
   *
   * pref_user_error: Whether User_error exceptions are preferred.
   * Default: false
   *)

val remove_pkg :
      ?pref_user_error:bool ->
      ?interactivity:interactivity ->
      ?protocol:collector ->
      package ->
	unit
  (* Removes a single installed package from the system. On success, the
   * function returns normally. The state of the package object is unchanged.
   * On failure, one of the defined error exceptions is raised.
   *
   * pref_user_error: Whether User_error exceptions are preferred.
   * Default: false
   *)

val build_pkg :
      ?pref_user_error:bool ->
      ?interactivity:interactivity ->
      ?protocol:collector ->
      ?catch_self:string option ->
      package ->
	unit
  (* Builds a single source package, installs it, and creates a binary
   * package for it. On success, the function returns normally. The
   * state of the package object is unchanged.  On failure, one of the
   * Godi_exec error exceptions is raised.
   *
   * If the source package sets the option SELF_UPDATE_PKG, this option
   * will be interpreted correctly.
   *
   * pref_user_error: Whether User_error exceptions are preferred.
   * Default: false
   *
   * catch_self: If non-None, a package name must be passed. After this
   * package has been installed, the function will raise Restart_recommended.
   * Default is [Some "godi-tools"]. The background is that godi_console
   * should be restarted immediately after it has been reinstalled.
   * For Windows platforms, the Restart_recommended exception contains the
   * godi_add command to install the package.
   *)

val add_pkg :
      ?pref_user_error:bool ->
      ?interactivity:interactivity ->
      ?protocol:collector ->
      package ->
	unit
  (* Adds a single binary package. On success, the function returns normally.
   * The state of the package object is unchanged.  On failure, one of the
   * defined error exceptions is raised.
   *
   * pref_user_error: Whether User_error exceptions are preferred.
   * Default: false
   *)

val test_conf_pkg :
      ?pref_user_error:bool ->
      ?interactivity:interactivity ->
      ?protocol:collector ->
      ?godi_conf:string ->
      package ->
	unit
  (* Tests the configurability of a single source package. This means,
   * it runs 'bmake configure', and outputs its results. On success, the
   * function returns normally. On failure, one of the
   * defined error exceptions is raised.
   *
   * ~godi_conf: If passed, this text file is used as replacement for
   * etc/godi.conf.
   *
   * pref_user_error: Whether User_error exceptions are preferred.
   * Default: false
   *)


(*
val perform :
      ?interactivity:interactivity ->
      ?protocol:collector ->
      package list ->
	unit
*)

(* - First removes all packages that have status `Remove or `Remove_dep.
 * - Builds all packages that have status `Build or `Build_dep.
 *
 * The input package list need not to be sorted.
 *
 * After every successful removal or build the list of user wishes is written
 * to disk.
 *
 * If a removal or build fails, the exception Command_failure is raised.
 * The function returns only normally if everything went right.
 *
 * After this function has been called, the package caches are out of
 * date, and need to be rescanned. The wish list should be again applied
 * to the packages.
 *)
